@@ -12,10 +12,10 @@ def get_image_type(filename: str):
     if not os.path.isfile(filename):
         print("[e] %s : file not found" % filename)
         sys.exit(-1)
-    with open(filename, 'rb') as file:
+    with open(filename, "rb") as file:
         file.seek(7, 0)
         magic = file.read(4)
-        if magic == b'IM4P':
+        if magic == b"IM4P":
             magic = "img4"
         else:
             return None
@@ -31,16 +31,16 @@ def decrypt_img(infile: str, magic: str, key: str, init_vector: str):
         print("[e] %s is not an IMG4 file" % infile)
         sys.exit(1)
 
-    outfile = infile + ".dec"
+    outfile = infile.replace("im4p", "bin")
     if magic == "img4":
         print("[i] decrypting %s to %s..." % (infile, outfile))
-        fnull = open(os.devnull, 'w')
+        fnull = open(os.devnull, "w")
 
         ivkey = init_vector + key
         logging.info("img4 -i %s %s %s", infile, outfile, ivkey)
 
         try:
-            subprocess.Popen(['img4', '-i', infile, outfile, ivkey],
+            subprocess.Popen(["img4", "-i", infile, outfile, ivkey],
                              stdout=fnull)
         except FileNotFoundError:
             print("[e] can't decrypt file, is img4 tool in $PATH ?")
@@ -52,8 +52,8 @@ def decrypt_img(infile: str, magic: str, key: str, init_vector: str):
 
 def get_kbag(firmware_image: str) -> str:
     """Return kbag of img4 file."""
-    out = subprocess.check_output(['img4', '-i', firmware_image, '-b'])
-    kbag = out.split()[0].decode('UTF-8')
+    out = subprocess.check_output(["img4", "-i", firmware_image, "-b"])
+    kbag = out.split()[0].decode("UTF-8")
     return kbag
 
 
